==> notbank-1.0.0a1-py3-none-any.whl: notbank_python_sdk/core/endpoints.py <==
from enum import Enum


class Endpoints(str, Enum):
    GET_OMS_DEPOSIT_FEES = "GetOMSDepositFees"
    GET_OMS_WITHDRAW_FEES = "GetOMSWithdrawFees"
    GET_OMS_FEES = "GetOMSFees"
    GET_OMS_FEE_TIERS = "GetOMSFeeTiers"
    GET_ACCOUNT_FEES = "GetAccountFees"
    GET_WITHDRAW_TEMPLATE_TYPES = "GetWithdrawTemplateTypes"
    GET_WITHDRAW_TEMPLATE = "GetWithdrawTemplate"
    GET_DEPOSIT_TEMPLATE_TYPES = "GetDepositTemplateTypes"
    GET_DEPOSIT_REQUEST_INFO_TEMPLATE = "GetDepositRequestInfoTemplate"
    LOCK_USERS = "LockUsers"
    UNLOCK_USER = "UnLockUser"
    WEB_AUTHENTICATE_USER = "WebAuthenticateUser"
    GET_LOGGED_IN_USER_BY_SESSION_TOKEN = "GetLoggedInUserBySessionToken"
    VALIDATE_SESSION_TOKEN = "ValidateSessionToken"
    GET_USER_LOGIN_AUDITS = "GetUserLoginAudits"
    GET_ACTIVE_USER_SESSIONS = "GetActiveUserSessions"
    UPDATE_DEPOSIT_TICKET = "UpdateDepositTicket"
    GET_ALL_WITHDRAW_TICKETS = "GetAllWithdrawTickets"
    GET_ALL_DEPOSIT_TICKETS = "GetAllDepositTickets"
    UPDATE_WITHDRAW_TICKET = "UpdateWithdrawTicket"
    GET_WITHDRAW_TICKET = "GetWithdrawTicket"
    GET_DEPOSIT_TICKET = "GetDepositTicket"
    CREATE_DEPOSIT_TICKET = "CreateDepositTicket"
    CREATE_WITHDRAW_TICKET = "CreateWithdrawTicket"
    GET_ACCOUNT_TRANSACTIONS = "GetAccountTransactions"
    GET_ACCOUNT_POSITIONS = "GetAccountPositions"
    GET_ACCOUNT_INSTRUMENT_STATISTICS = "GetAccountInstrumentStatistics"
    GET_ACCOUNT_SETTLEMENT_POSITIONS = "GetAccountSettlementPositions"
    GET_ACCOUNT_INFO = "GetAccountInfo"
    LOGOUT = "LogOut"
    GET_VALIDATE_2FA_REQUIRED_ENDPOINTS = "GetValidate2FARequiredEndpoints"
    GET_DEPOSIT_TICKETS = "GetDepositTickets"
    GET_DEPOSIT_INFO = "GetDepositInfo"
    GET_NEW_DEPOSIT_ADDRESS = "GetNewDepositAddress"
    GET_ALL_DEPOSIT_REQUEST_INFO_TEMPLATES = "GetAllDepositRequestInfoTemplates"
    GET_DEPOSITS = "GetDeposits"
    GET_ACCOUNT_DEPOSIT_TRANSACTIONS = "GetAccountDepositTransactions"
    GET_WITHDRAW_FEE = "GetWithdrawFee"
    GET_DEPOSIT_FEE = "GetDepositFee"
    GET_PRODUCT = "GetProduct"
    GET_PRODUCTS = "GetProducts"
    GET_INSTRUMENT = "GetInstrument"
    GET_VERIFICATION_LEVEL_CONFIGS = "GetVerificationLevelConfigs"
    GET_ORDER_FEE = "GetOrderFee"
    GET_INSTRUMENT_VERIFICATION_LEVEL_CONFIG = "GetInstrumentVerificationLevelConfig"
    AUTHENTICATE_2FA = "Authenticate2FA"
    GET_INSTRUMENTS = "GetInstruments"
    PING = "Ping"
    HEALTH_CHECK = "HealthCheck"
    SEND_ORDER_LIST = "SendOrderList"
    SEND_CANCEL_LIST = "SendCancelList"
    SEND_CANCEL_REPLACE_LIST = "SendCancelReplaceList"
    MODIFY_ORDER = "ModifyOrder"
    CANCEL_ALL_ORDERS = "CancelAllOrders"
    GET_ORDER_STATUS = "GetOrderStatus"
    GET_ORDERS_HISTORY = "GetOrdersHistory"
    GET_TRADES_HISTORY = "GetTradesHistory"
    GET_ORDER_HISTORY_BY_ORDER_ID = "GetOrderHistoryByOrderId"
    GET_TICKER_HISTORY = "GetTickerHistory"
    GET_LAST_TRADES = "GetLastTrades"
    GET_LEVEL1_SUMMARY = "GetLevel1Summary"
    GET_LEVEL1_SUMMARY_MIN = "GetLevel1SummaryMin"
    GET_OPEN_TRADE_REPORTS = "GetOpenTradeReports"
    GET_ORDERS = "GetOrders"
    GET_ORDER_HISTORY = "GetOrderHistory"
    SEND_ORDER = "SendOrder"
    CANCEL_REPLACE_ORDER = "CancelReplaceOrder"
    CANCEL_ORDER = "CancelOrder"
    TRANSFER_FUNDS = "TransferFunds"
    CREATE_ACCOUNT_WITHDRAW_INFO = "CreateAccountWithdrawInfo"
    CONFIRM_WITHDRAW_INFO = "ConfirmWithdrawInfo"
    GET_OPEN_ORDERS = "GetOpenOrders"
    GET_ACCOUNT_TRADES = "GetAccountTrades"
    SUMMARY = "Summary"
    TICKER = "Ticker"
    ORDER_BOOK = "OrderBook"
    TRADES = "Trades"
    GET_EARLIEST_TICK_TIME = "GetEarliestTickTime"
    GET_L2_SNAPSHOT = "GetL2Snapshot"
    DELETE_ACCOUNT_WITHDRAW_INFO = "DeleteAccountWithdrawInfo"
    GET_ACCOUNT_WITHDRAW_INFOS = "GetAccountWithdrawInfos"
    UPDATE_ACCOUNT_WITHDRAW_INFO = "UpdateAccountWithdrawInfo"
    GET_LEVEL1 = "GetLevel1"
    GET_ENUMS = "GetEnums"
    GET_USER_ACCOUNTS = "GetUserAccounts"
    GET_USER_DEVICES = "GetUserDevices"
    GET_USER_INFO = "GetUserInfo"
    GET_ACCOUNT_WITHDRAW_TRANSACTIONS = "GetAccountWithdrawTransactions"
    GENERATE_TRADE_ACTIVITY_REPORT = "GenerateTradeActivityReport"
    GENERATE_TRANSACTION_ACTIVITY_REPORT = "GenerateTransactionActivityReport"
    GENERATE_PRODUCT_DELTA_ACTIVITY_REPORT = "GenerateProductDeltaActivityReport"
    GENERATE_PNL_ACTIVITY_REPORT = "GeneratePnLActivityReport"
    SCHEDULE_TRADE_ACTIVITY_REPORT = "ScheduleTradeActivityReport"
    SCHEDULE_TRANSACTION_ACTIVITY_REPORT = "ScheduleTransactionActivityReport"
    SCHEDULE_PRODUCT_DELTA_ACTIVITY_REPORT = "ScheduleProductDeltaActivityReport"
    SCHEDULE_PROFIT_AND_LOSS_ACTIVITY_REPORT = "ScheduleProfitAndLossActivityReport"
    CANCEL_USER_REPORT = "CancelUserReport"
    GET_USER_REPORT_WRITER_RESULT_RECORDS = "GetUserReportWriterResultRecords"
    GET_USER_REPORT_TICKETS = "GetUserReportTickets"
    REMOVE_USER_REPORT_TICKET = "RemoveUserReportTicket"
    GET_USER_REPORT_TICKETS_BY_STATUS = "GetUserReportTicketsByStatus"
    DOWNLOAD_DOCUMENT = "DownloadDocument"
    DOWNLOAD_DOCUMENT_SLICE = "DownloadDocumentSlice"
    GET_USER_PERMISSIONS = "GetUserPermissions"
    EDIT_INSTRUMENT_VERIFICATION_LEVEL_CONFIG = "EditInstrumentVerificationLevelConfig"
    ADD_SINGLE_VERIFICATION_LEVEL_CONFIG = "AddSingleVerificationLevelConfig"
    SET_OMS_WITHDRAW_FEE = "SetOMSWithdrawFee"
    SET_OMS_DEPOSIT_FEE = "SetOMSDepositFee"
    EDIT_VERIFICATION_LEVEL_CONFIG = "EditVerificationLevelConfig"
    SET_OMS_FEE = "SetOMSFee"
    SET_CHART_DATA = "SetChartData"


class WebSocketEndpoint(str, Enum):
    SUBSCRIBE_LEVEL2 = "SubscribeLevel2"
    UNSUBSCRIBE_LEVEL2 = "UnsubscribeLevel2"
    SUBSCRIBE_LEVEL1 = "SubscribeLevel1"
    UNSUBSCRIBE_LEVEL1 = "UnsubscribeLevel1"
    SUBSCRIBE_TRADES = "SubscribeTrades"
    UNSUBSCRIBE_TRADES = "UnsubscribeTrades"
    SUBSCRIBE_TICKER = "SubscribeTicker"
    UNSUBSCRIBE_TICKER = "UnsubscribeTicker"
    SUBSCRIBE_ACCOUNT_EVENTS = "SubscribeAccountEvents"
    UNSUBSCRIBE_ACCOUNT_EVENTS = "UnSubscribeAccountEvents"
    SUBSCRIBE_ORDER_STATE_EVENTS = "SubscribeOrderStateEvents"
    UNSUBSCRIBE_ORDER_STATE_EVENTS = "UnSubscribeOrderStateEvents"
    WEB_AUTHENTICATE_USER = "WebAuthenticateUser"
    AUTHENTICATE2FA = "Authenticate2FA"
    ACCOUNT_EVENT_TRANSACTION = "TransactionEvent"
    ACCOUNT_EVENT_WITHDRAW_TICKET_UPDATE = "WithdrawTicketUpdateEvent"
    ACCOUNT_EVENT_ACCOUNT_POSITION = "AccountPositionEvent"
    ACCOUNT_EVENT_ORDER_TRADE = "OrderTradeEvent"
    ACCOUNT_EVENT_ORDER_STATE = "OrderStateEvent"
    ACCOUNT_EVENT_DEPOSIT_TICKET_UPDATE = "DepositTicketUpdateEvent"
    ACCOUNT_EVENT_ACCOUNT_INFO_UPDATE = "AccountInfoUpdateEvent"
    ACCOUNT_EVENT_CANCEL_ORDER_REJECT = "CancelOrderRejectEvent"
    ACCOUNT_EVENT_DEPOSIT = "DepositEvent"
    UPDATE_TICKER = "TickerDataUpdateEvent"
    SUBSCRIBE_LEVEL_1 = "SubscribeLevel1"
    UPDATE_LEVEL_1 = "Level1UpdateEvent"
    SUBSCRIBE_LEVEL_2 = "SubscribeLevel2"
    UPDATE_LEVEL_2 = "Level2UpdateEvent"

==> notbank-1.1.1a1-py3-none-any.whl: notbank_python_sdk/core/endpoints.py <==
from enum import Enum


class Endpoints(str, Enum):

    # account
    GET_ACCOUNT_TRANSACTIONS = "GetAccountTransactions"
    GET_ACCOUNT_POSITIONS = "GetAccountPositions"
    GET_ACCOUNT_INSTRUMENT_STATISTICS = "GetAccountInstrumentStatistics"
    GET_ACCOUNT_INFO = "GetAccountInfo"

    # authentication
    # TODO: missing: Authenticate
    AUTHENTICATE = "Authenticate"
    AUTHENTICATE_USER = "AuthenticateUser"
    WEB_AUTHENTICATE_USER = "WebAuthenticateUser"
    LOGOUT = "LogOut"

    # # fee
    GET_WITHDRAW_FEE = "GetWithdrawFee"
    GET_DEPOSIT_FEE = "GetDepositFee"
    GET_OMS_DEPOSIT_FEES = "GetOMSDepositFees"
    GET_OMS_WITHDRAW_FEES = "GetOMSWithdrawFees"
    GET_ACCOUNT_FEES = "GetAccountFees"
    GET_ORDER_FEE = "GetOrderFee"

    # instrument
    GET_INSTRUMENT = "GetInstrument"
    GET_INSTRUMENTS = "GetInstruments"
    GET_INSTRUMENT_VERIFICATION_LEVEL_CONFIG = "GetInstrumentVerificationLevelConfig"

    # product
    GET_PRODUCT = "GetProduct"
    GET_PRODUCTS = "GetProducts"
    GET_VERIFICATION_LEVEL_CONFIG = "GetVerificationLevelConfig"

    # reports
    GENERATE_TRADE_ACTIVITY_REPORT = "GenerateTradeActivityReport"
    GENERATE_TRANSACTION_ACTIVITY_REPORT = "GenerateTransactionActivityReport"
    GENERATE_PRODUCT_DELTA_ACTIVITY_REPORT = "GenerateProductDeltaActivityReport"
    GENERATE_PNL_ACTIVITY_REPORT = "GeneratePnLActivityReport"
    SCHEDULE_TRADE_ACTIVITY_REPORT = "ScheduleTradeActivityReport"
    SCHEDULE_TRANSACTION_ACTIVITY_REPORT = "ScheduleTransactionActivityReport"
    SCHEDULE_PRODUCT_DELTA_ACTIVITY_REPORT = "ScheduleProductDeltaActivityReport"
    SCHEDULE_PROFIT_AND_LOSS_ACTIVITY_REPORT = "ScheduleProfitAndLossActivityReport"
    CANCEL_USER_REPORT = "CancelUserReport"
    GET_USER_REPORT_WRITER_RESULT_RECORDS = "GetUserReportWriterResultRecords"
    GET_USER_REPORT_TICKETS = "GetUserReportTickets"
    REMOVE_USER_REPORT_TICKET = "RemoveUserReportTicket"
    GET_USER_REPORT_TICKETS_BY_STATUS = "GetUserReportTicketsByStatus"
    DOWNLOAD_DOCUMENT = "DownloadDocument"
    DOWNLOAD_DOCUMENT_SLICE = "DownloadDocumentSlice"

    # ping
    PING = "Ping"
    HEALTH_CHECK = "HealthCheck"

    # trading
    SEND_ORDER_LIST = "SendOrderList"
    SEND_CANCEL_LIST = "SendCancelList"
    SEND_CANCEL_REPLACE_LIST = "SendCancelReplaceList"
    MODIFY_ORDER = "ModifyOrder"
    CANCEL_ALL_ORDERS = "CancelAllOrders"
    GET_ORDER_STATUS = "GetOrderStatus"
    GET_ORDERS_HISTORY = "GetOrdersHistory"
    GET_TRADES_HISTORY = "GetTradesHistory"
    GET_ORDER_HISTORY_BY_ORDER_ID = "GetOrderHistoryByOrderId"
    GET_TICKER_HISTORY = "GetTickerHistory"
    GET_LAST_TRADES = "GetLastTrades"
    GET_LEVEL1_SUMMARY = "GetLevel1Summary"
    GET_LEVEL1_SUMMARY_MIN = "GetLevel1SummaryMin"
    GET_OPEN_TRADE_REPORTS = "GetOpenTradeReports"
    GET_ORDERS = "GetOrders"
    GET_ORDER_HISTORY = "GetOrderHistory"
    SEND_ORDER = "SendOrder"
    CANCEL_REPLACE_ORDER = "CancelReplaceOrder"
    CANCEL_ORDER = "CancelOrder"
    GET_OPEN_ORDERS = "GetOpenOrders"
    GET_ACCOUNT_TRADES = "GetAccountTrades"
    SUMMARY = "Summary"
    TICKER = "Ticker"
    ORDER_BOOK = "OrderBook"
    TRADES = "Trades"
    GET_L2_SNAPSHOT = "GetL2Snapshot"
    GET_LEVEL1 = "GetLevel1"
    GET_ENUMS = "GetEnums"

    # user
    GET_USER_ACCOUNTS = "GetUserAccounts"
    GET_USER_DEVICES = "GetUserDevices"
    GET_USER_INFO = "GetUserInfo"
    GET_USER_PERMISSIONS = "GetUserPermissions"


class WebSocketEndpoint(str, Enum):
    SUBSCRIBE_LEVEL2 = "SubscribeLevel2"
    UNSUBSCRIBE_LEVEL2 = "UnsubscribeLevel2"
    SUBSCRIBE_LEVEL1 = "SubscribeLevel1"
    UNSUBSCRIBE_LEVEL1 = "UnsubscribeLevel1"
    SUBSCRIBE_TRADES = "SubscribeTrades"
    UNSUBSCRIBE_TRADES = "UnsubscribeTrades"
    SUBSCRIBE_TICKER = "SubscribeTicker"
    UNSUBSCRIBE_TICKER = "UnsubscribeTicker"
    SUBSCRIBE_ACCOUNT_EVENTS = "SubscribeAccountEvents"
    UNSUBSCRIBE_ACCOUNT_EVENTS = "UnSubscribeAccountEvents"
    SUBSCRIBE_ORDER_STATE_EVENTS = "SubscribeOrderStateEvents"
    UNSUBSCRIBE_ORDER_STATE_EVENTS = "UnSubscribeOrderStateEvents"

    WEB_AUTHENTICATE_USER = "WebAuthenticateUser"
    ACCOUNT_EVENT_TRANSACTION = "TransactionEvent"
    ACCOUNT_EVENT_WITHDRAW_TICKET_UPDATE = "WithdrawTicketUpdateEvent"
    ACCOUNT_EVENT_ACCOUNT_POSITION = "AccountPositionEvent"
    ACCOUNT_EVENT_ORDER_TRADE = "OrderTradeEvent"
    ACCOUNT_EVENT_ORDER_STATE = "OrderStateEvent"
    ACCOUNT_EVENT_DEPOSIT_TICKET_UPDATE = "DepositTicketUpdateEvent"
    ACCOUNT_EVENT_ACCOUNT_INFO_UPDATE = "AccountInfoUpdateEvent"
    ACCOUNT_EVENT_CANCEL_ORDER_REJECT = "CancelOrderRejectEvent"
    ACCOUNT_EVENT_DEPOSIT = "DepositEvent"
    UPDATE_TICKER = "TickerDataUpdateEvent"
    SUBSCRIBE_LEVEL_1 = "SubscribeLevel1"
    UPDATE_LEVEL_1 = "Level1UpdateEvent"
    SUBSCRIBE_LEVEL_2 = "SubscribeLevel2"
    UPDATE_LEVEL_2 = "Level2UpdateEvent"
